@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
 
+import json
+
+
 class GroupChat(object):
     def __init__(self,
                  id,
@@ -12,3 +15,11 @@ class GroupChat(object):
     def de_json(data):
         return GroupChat(id=data.get('id', None),
                          title=data.get('title', None))
+
+    def to_json(self):
+        json_data = {'id': self.id,
+                     'title': self.title}
+        return json.dumps(json_data)
+
+    def __str__(self):
+        return self.to_json()
