@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
 
+import json
+
+
 class PhotoSize(object):
     def __init__(self,
                  file_id,
@@ -18,3 +21,14 @@ class PhotoSize(object):
                          width=data.get('width', None),
                          height=data.get('height', None),
                          file_size=data.get('file_size', None))
+
+    def to_json(self):
+        json_data = {'file_id': self.file_id,
+                     'width': self.width,
+                     'height': self.height}
+        if self.file_size:
+            json_data['file_size'] = self.file_size
+        return json.dumps(json_data)
+
+    def __str__(self):
+        return self.to_json()
